@@ -11,14 +11,26 @@ class SESEmailBackend(EmailBackend):
         super().__init__()
         self.ses = boto3.client('ses')
 
-    def send_email(self, template: EmailTemplate, to: str, subject: str, variables: Optional[dict[str, str]] = None):
+    def send_email(
+        self,
+        *,
+        template: EmailTemplate,
+        subject: str,
+        from_: str,
+        to: str,
+        variables: Optional[dict[str, str]] = None
+    ):
+        variables = {
+            'subject': subject,
+            **(variables or {})
+        }
         self.ses.send_templated_email(
-            Source='noreply@pycon.it',
+            Source=from_,
             Destination={
                 'ToAddresses': [
                     to
                 ]
             },
             Template=f'pythonit-pastaporto-{template}',
-            TemplateData=json.dumps(variables if variables else {})
+            TemplateData=json.dumps(variables)
         )
